#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <stdlib.h>
#include <stdio.h>
#include <gtk/gtk.h>
#include <panel-applet.h>
#include "hddtemp-applet.h"
#include "preferences.h"
#include "gconf-keys.h"

static const char Hddtempmenuxml [] =
   "<popup name=\"button3\">\n"
   "   <menuitem name=\"Properties Item\" "
   "             verb=\"HddtempPreferences\" "
   "           _label=\"_Preferences\"\n"
   "          pixtype=\"stock\" "
   "          pixname=\"gtk-properties\"/>\n"
   "   <menuitem name=\"About Item\" "
   "             verb=\"HddtempAbout\" "
   "           _label=\"_About\"\n"
   "          pixtype=\"stock\" "
   "          pixname=\"gnome-stock-about\"/>\n"
   "</popup>\n";

void gconf_set_defaults(HddtempApplet *applet)
{
	if (!(panel_applet_gconf_get_bool(applet->applet,gconf_keys[IS_SETUP],NULL)))
	{
		panel_applet_gconf_set_bool(applet->applet, gconf_keys[IS_SETUP], TRUE, NULL);
		panel_applet_gconf_set_bool(applet->applet, gconf_keys[FAHRENHEIT], FALSE, NULL);
		panel_applet_gconf_set_bool(applet->applet, gconf_keys[SHOW_LABELS], TRUE, NULL);
		panel_applet_gconf_set_bool(applet->applet, gconf_keys[SHOW_UNITS], TRUE, NULL);
		panel_applet_gconf_set_int(applet->applet, gconf_keys[TIMEOUT], 3000, NULL);
	}
}
void display_preferences_dialog (BonoboUIComponent *uic, HddtempApplet *applet)
{
	if (applet->_preferences)
		gtk_widget_show(applet->preferences);
	else
		create_preferences_window(applet);
}

void display_about_dialog (BonoboUIComponent *uic, HddtempApplet *applet)
{
	const gchar *authors[] = { "Julen Landa Alustiza", NULL };
	const gchar *documenters[] = { "Julen Landa Alustiza", NULL };
	const gchar translators[] = "Julen Landa Alustiza";
	applet->about = gnome_about_new ("gnome-hddtemp-applet", VERSION,
                        _("(C) Julen Landa Alustiza <julen@mundurat.net>"),
                        "",
                        authors,
                        documenters,
                        translators,
                        NULL);
    gtk_container_set_border_width (GTK_CONTAINER (applet->about), 5);
	gtk_widget_show(applet->about);
}

char *retrieve_temp(HddtempApplet *applet, char *device)
{
	static char temperature[2];
	char str[]="sudo /usr/sbin/hddtemp -n ";
	FILE *stream;
	stream = popen(strcat(str,device),"r");
	fscanf(stream,"%s",&temperature);
	pclose(stream);
	if (panel_applet_gconf_get_bool(applet->applet,gconf_keys[FAHRENHEIT]))
	{
		int i;
		i = ((9*atoi(temperature))/5) + 32;
		sprintf(temperature,"%d", i);
	}
	return &temperature;
}
void draw_sensors(HddtempApplet *applet)
{
	applet->temp = gtk_label_new (NULL);
	if (panel_applet_gconf_get_bool(applet->applet,gconf_keys[FAHRENHEIT]))
		applet->unit = gtk_label_new("ºF");
	else
		applet->unit = gtk_label_new("ºC");
	applet->name = gtk_label_new("/dev/hda");
	applet->hbox = gtk_hbox_new (FALSE, 2);
	gtk_box_pack_start(GTK_BOX(applet->hbox),applet->temp,FALSE,FALSE,0);
	gtk_widget_show(applet->temp);
	gtk_box_pack_start(GTK_BOX(applet->hbox),applet->unit,FALSE,FALSE,0);
	if (panel_applet_gconf_get_bool(applet->applet,gconf_keys[SHOW_UNITS], NULL))
		gtk_widget_show(applet->unit);
	gtk_box_pack_start(GTK_BOX(applet->hbox),applet->name,FALSE,FALSE,3);
	if (panel_applet_gconf_get_bool(applet->applet,gconf_keys[SHOW_LABELS], NULL))
		gtk_widget_show(applet->name);
	gtk_container_add (GTK_CONTAINER (applet->applet), applet->hbox);	
	gtk_widget_show(applet->hbox);
}

void sensors_update(HddtempApplet *applet)
{
	char *str;
	str = retrieve_temp(applet,"/dev/hda");
	gtk_label_set_text(GTK_LABEL(applet->temp),str);
	if (panel_applet_gconf_get_bool(applet->applet,gconf_keys[FAHRENHEIT],NULL))
		gtk_label_set_text(GTK_LABEL(applet->unit),"ºF");
	else
		gtk_label_set_text(GTK_LABEL(applet->unit),"ºC");
	
	if (panel_applet_gconf_get_bool(applet->applet,gconf_keys[SHOW_UNITS], NULL))
		gtk_widget_show(applet->unit);
	else
		gtk_widget_hide(applet->unit);
	if (panel_applet_gconf_get_bool(applet->applet,gconf_keys[SHOW_LABELS], NULL))
		gtk_widget_show(applet->name);
	else
		gtk_widget_hide(applet->name);
	gtk_widget_show(applet->temp);
}
void applet_update(HddtempApplet *applet)
{
	sensors_update(applet);
	
}

static const BonoboUIVerb menu_verbs [] = {
        BONOBO_UI_VERB ("HddtempPreferences", display_preferences_dialog),
        BONOBO_UI_VERB ("HddtempAbout", display_about_dialog),
        BONOBO_UI_VERB_END
};	

static gboolean
applet_factory (PanelApplet *appletin,
   const gchar *iid,
   gpointer data)
{
	HddtempApplet *applet;
	applet = g_new0(HddtempApplet, 1);
	applet->_preferences = FALSE;
	applet->applet = appletin;
	applet->client = gconf_client_get_default ();
	panel_applet_add_preferences (PANEL_APPLET (applet->applet),
        "/schemas/apps/hddtemp_applet/prefs",
        NULL);
	gconf_set_defaults(applet);
	if (strcmp (iid, applet_iid) != 0)
		return FALSE;	
	draw_sensors(applet);
	gtk_widget_show (GTK_WIDGET (applet->applet));
	applet_update(applet);
	applet->updatetimer = g_timeout_add(panel_applet_gconf_get_int(applet->applet,gconf_keys[TIMEOUT], NULL),(GSourceFunc) applet_update,applet);
	panel_applet_setup_menu (PANEL_APPLET (applet->applet),
                         Hddtempmenuxml,
                         menu_verbs,
                         applet);
}

PANEL_APPLET_BONOBO_FACTORY (factory_iid,
		PANEL_TYPE_APPLET,
		"HDDTemp-Applet", "0",
		applet_factory, NULL);
