/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
#include "preferences.h"
static void preferences_close(HddtempApplet *applet)
{
	panel_applet_gconf_set_bool(applet->applet, gconf_keys[IS_SETUP], TRUE, NULL);
	gtk_widget_hide(applet->preferences);
}
static void preferences_showunits_cb(GtkToggleButton *button, HddtempApplet *applet)
{
	gboolean value;
	g_object_get(button, "active", &value, NULL);
	panel_applet_gconf_set_bool(applet->applet, gconf_keys[SHOW_UNITS], value, NULL);
	sensors_update(applet);
}

static void preferences_showlabels_cb(GtkToggleButton *button, HddtempApplet *applet)
{
	gboolean value;
	g_object_get(button, "active", &value, NULL);
	panel_applet_gconf_set_bool(applet->applet, gconf_keys[SHOW_LABELS], value, NULL);
	sensors_update(applet);
}
static void preferences_fahrenheit_cb(GtkToggleButton *button, HddtempApplet *applet)
{
	gboolean value;
	g_object_get(button, "active", &value, NULL);
	panel_applet_gconf_set_bool(applet->applet, gconf_keys[FAHRENHEIT], value, NULL);
	sensors_update(applet);
}

static void preferences_timeout_cb(GtkToggleButton *button, HddtempApplet *applet)
{
	guint value;
	value = gtk_spin_button_get_value_as_int(button)*1000;
	panel_applet_gconf_set_int(applet->applet, gconf_keys[TIMEOUT], value, NULL);
	sensors_update(applet);
	g_source_remove(applet->updatetimer);
	applet->updatetimer = g_timeout_add(value, (GSourceFunc)applet_update, applet);
}

void create_preferences_window(HddtempApplet *applet)
{
	GtkWidget *notebook, *globalpagevbox;
	GtkWidget *checkb_showunit, *checkb_showlabel, *checkb_fahrenheit;
	GtkWidget *timeout_spin, *timeout_label, *timeout_hbox;
	GtkObject *timeout_adj;
	applet->preferences = gtk_dialog_new_with_buttons("Hddtemp Applet Preferences",
								   NULL,
								   GTK_DIALOG_NO_SEPARATOR,
								   GTK_STOCK_CLOSE,
								   GTK_RESPONSE_CLOSE,
								   NULL);
	g_object_set(applet->preferences, 
		     "border-width", 12,
		     "default-width", 300,
		     "default-height", 350,
		     NULL);
	
	gtk_box_set_homogeneous(GTK_BOX(GTK_DIALOG(applet->preferences)->vbox), FALSE);
	
	gtk_box_set_spacing(GTK_BOX(GTK_DIALOG(applet->preferences)->vbox), 5);

	//gtk_dialog_set_default_response(GTK_DIALOG(applet->preferences), GTK_RESPONSE_CLOSE);
	
	//notebook insides:
	checkb_showunit = gtk_check_button_new_with_mnemonic("Show _units");
	g_signal_connect(checkb_showunit, "toggled", G_CALLBACK(preferences_showunits_cb), applet);
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkb_showunit),panel_applet_gconf_get_bool(applet->applet, gconf_keys[SHOW_UNITS], NULL));
	checkb_showlabel = gtk_check_button_new_with_mnemonic("Show _labels");
	g_signal_connect(checkb_showlabel, "toggled", G_CALLBACK(preferences_showlabels_cb), applet);
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkb_showlabel),panel_applet_gconf_get_bool(applet->applet, gconf_keys[SHOW_LABELS], NULL));
	checkb_fahrenheit = gtk_check_button_new_with_mnemonic("Use _fahrenheit for temperature sensors");
	g_signal_connect(checkb_fahrenheit, "toggled", G_CALLBACK(preferences_fahrenheit_cb), applet);
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkb_fahrenheit),panel_applet_gconf_get_bool(applet->applet, gconf_keys[FAHRENHEIT], NULL));
	timeout_spin = gtk_spin_button_new(GTK_ADJUSTMENT(gtk_adjustment_new((gdouble) (panel_applet_gconf_get_int(applet->applet, gconf_keys[TIMEOUT])/1000),0.5,10.0,0.5,1.0,0.0)),0.5,1);
	timeout_label = gtk_label_new("Refresh delay (secs)");
	timeout_hbox = gtk_hbox_new(FALSE,2);
	g_signal_connect(timeout_spin, "value-changed", G_CALLBACK(preferences_timeout_cb), applet);
	gtk_box_pack_start(GTK_BOX(timeout_hbox), GTK_WIDGET(timeout_label), FALSE, FALSE, 0);
	gtk_box_pack_start(GTK_BOX(timeout_hbox), GTK_WIDGET(timeout_spin), FALSE, FALSE, 0);
	//notebook
	notebook = gtk_notebook_new();
	globalpagevbox = gtk_vbox_new(FALSE, 3);
	gtk_box_pack_start(GTK_BOX(globalpagevbox), GTK_WIDGET(checkb_showunit), FALSE, FALSE, 0);
	gtk_box_pack_start(GTK_BOX(globalpagevbox), GTK_WIDGET(checkb_showlabel), FALSE, FALSE, 0);
	gtk_box_pack_start(GTK_BOX(globalpagevbox), GTK_WIDGET(checkb_fahrenheit), FALSE, FALSE, 0);
	gtk_box_pack_start(GTK_BOX(globalpagevbox), GTK_WIDGET(timeout_hbox), FALSE, FALSE, 0);
	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), globalpagevbox, gtk_label_new(_("Global Options")));
	gtk_box_pack_start_defaults(GTK_BOX(GTK_DIALOG(applet->preferences)->vbox), notebook);
	g_signal_connect_swapped(applet->preferences,
			     "response", G_CALLBACK(preferences_close), 
				 applet);
	applet->_preferences = TRUE; 
	gtk_widget_show_all(applet->preferences);
}
